--[=====[-------------- Modules --------------]=====]--
local states = require 'states'

--[=====[-------------- Variables --------------]=====]--
local menu = {}
local mclick, menufont, selector
local max_options = 2
local music, introm


--[=====[-------------- Functions --------------]=====]--

function menu:mainmenu()
    self.menu = 'main'
    max_options = 2
    -- Tell game that it needs to initialize everything
    states.game.initialize = true
    states:activate(self)
end


function menu:pausemenu()
  self.menu = 'pause'
  max_options = 4
  states:activate(self)
end


--[=====[-------------- Events --------------]=====]--

function menu:load()
    mclick = love.audio.newSource('music/menu click.wav', "static")
    menufont = love.graphics.newFont('PixelFJVerdana12pt_0.ttf', 20)

    -- This activates the first option only the first time
    selector = 1

    music = 'play'
    --introm = love.audio.newSource('music/intro.wav', "static") -- intro music here
end


function menu:when_activated()
    love.graphics.setFont(menufont)

    if self.menu == 'main' then
        -- This makes music only play when in main menu
        if music == 'play' then
            --introm:setLooping(true)
            --introm:play(-1)
            --vol = 1
            --introm:setVolume(vol)
        end
    end

    if self.menu == 'pause' then
        selector = 3
    else
        selector = 1
    end
end


function menu:when_deactivated()
    if self.menu == 'main' then
        if music == 'play' then
            --introm:stop()
        end
    end
end


-- not necessary:
--function menu:update(dt)
--end


function menu:draw()
    if self.menu == 'main' then
        local sx1 = selector == 1 and 150 or 100
        local sx2 = selector == 2 and 150 or 100
        love.graphics.printf("Start", sx1, 100, 800)
        love.graphics.printf("Info", sx2, 150, 800)
    elseif self.menu == 'pause' then
        local sx1 = selector == 1 and 150 or 100
        local sx2 = selector == 2 and 150 or 100
        local sx3 = selector == 3 and 150 or 100
        local sx4 = selector == 4 and 150 or 100
        love.graphics.printf("Exit", sx1, 100, 800)
        love.graphics.printf("Save", sx2, 150, 800)
        love.graphics.printf("Resume", sx3, 200, 800)
        love.graphics.printf("Settings", sx4, 250, 800)
    end
end


function menu:keypressed(localekey, key)
    if key == "s" or key == "down" then
        selector = selector + 1
        if selector > max_options then selector = 1 end
    elseif key == "w" or key == "up" then
        selector = selector - 1
        if selector < 1 then selector = max_options end
    elseif key == "return" then
        if self.menu == 'main' then
            mclick:play()
            if selector == 1 then
                states:activate(states.game)
            elseif selector == 2 then
                states:activate(states.info)
            end
        elseif self.menu == 'pause' then
            if selector ~= 1 then -- don't play sound when choosing "Exit"
                mclick:play()
            end

            if selector == 1 then
                self:mainmenu()
            elseif selector == 2 then
                -- TODO: Save game
                print("save")
            elseif selector == 3 then
                states:activate(states.game)
            elseif selector == 4 then
                -- TODO: Create settings screen
                --states:activate(states.settings)
                print("settings")
            end
        end
    elseif key == "escape" then
        if self.menu == 'main' then
            love.event.quit()
        else
            self:mainmenu()
        end
    end
end


return menu
